{% load staticfiles %}

<!DOCTYPE html>
<html lang="en">
<head>
    <title>{% block title %}{% endblock %} - {{SITE_META.site_name}}</title>

    {% include 'partials/seo.html' %}
    {% include 'partials/icons.html' %}

    <link href="https://maxcdn.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.min.css" rel="stylesheet">
    <link href='https://fonts.googleapis.com/css?family=Open+Sans:400,700,300italic' rel='stylesheet' type='text/css'>
    <link rel="stylesheet" type="text/css" href="{% static 'css/bootstrap.journal.min.css' %}" />
    <link rel="stylesheet" type="text/css" href="{% static 'css/dataTables.bootstrap.css' %}" />
    <link rel="stylesheet" type="text/css" href="{% static 'css/custom.css' %}" />
    <link rel="stylesheet" type="text/css" href="{% static 'css/city_custom.css' %}" />

    {% block extra_css %}{% endblock %}

</head>
<body>

    <nav class="navbar navbar-default navbar-fixed-top">
        <div class="container-fluid container-fluid-nav">
            <div id="nav-title">
                <a class="navbar-brand" href="/">
                    <img id="logo" src="{% static IMAGES.logo %}"></img>
                    <span id="logo-text">{{ CITY_NAME_SHORT }} Councilmatic</span>
                </a>
            </div>
            <ul id="nav-items">
                <li>
                    <a href="/about/">About</a>
                </li>
                <li>
                    <a href='/council-members/'>{{ CITY_VOCAB.COUNCIL_MEMBERS }}</a>
                </li>
                <li>
                    <a href='/committees/'>Committees</a>
                </li>
                <li>
                    <a href='/events/'>{{ CITY_VOCAB.EVENTS }}</a>
                </li>
                <li>
                    <a href="/search/">Legislation</a>
                </li>
        {% if USING_NOTIFICATIONS and request.user.is_authenticated %}
        <li>
            <div class="dropdown">
                <a class="dropdown-toggle" data-toggle="dropdown" title="Account">
                    <i class="fa fa-user" aria-hidden="true"></i>
                    <span class="caret"></span>
                </a>
                <ul class="dropdown-menu dropdown-menu-right">
                    <li class="non-link text-muted small">{{request.user.email}}</li>
                    <li role="separator" class="divider"></li>
                    <li>
                        <a href="/account/subscriptions">
                            <i class="fa fa-bullhorn fa-fw" aria-hidden="true"></i>
                            Manage Alerts
                        </a>
                    </li>
                    <li>
                        <a href="/logout/">
                            <i class="fa fa-sign-out fa-fw" aria-hidden="true"></i>
                            Sign out
                        </a>
                    </li>
                </ul>
            </div>
        </li>
        </div>
        {% endif %}
        {% if USING_NOTIFICATIONS and not request.user.is_authenticated %}
        <li>
            <a href="/login/" title="Sign in">
                <i class="fa fa-sign-in" aria-hidden="true"></i>
            </a>
        </li>
        {% endif %}
            </ul>

        </div>
    </nav>

    {% block full_content %}
    {% endblock %}

    <script src="{% static 'js/jquery-1.10.1.min.js' %}"></script>
    <script src="{% static 'js/bootstrap.min.js' %}"></script>

    {% block extra_js %}{% endblock %}

    <script>
        var analyticsTrackingCode = '{{ANALYTICS_TRACKING_CODE}}';
    </script>
    <script src="{% static 'js/analytics_lib.js' %}"></script>

</body>
</html>
