<div class='well info-blurb'>
    <h4><i class='fa fa-fw fa-info-circle'></i> What are these {{ CITY_VOCAB.EVENTS | lower}}?</h4>

    {{ ABOUT_BLURBS.EVENTS | safe }}

    <p><a href='/about/#about-city-council'>More on how City Council works &raquo;</a></p>
</div>