# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-10-19 17:24
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0011_auto_20161013_1541'),
        ('councilmatic_core', '0026_auto_20161017_1641'),
    ]

    operations = [
    ]
